==> org.eclipse.scout.sdk.ui.source_3.8.2.201302111336.jar: org/eclipse/scout/sdk/ui/fields/proposal/nls/NlsTextContentProvider.java <==
/*******************************************************************************
 * Copyright (c) 2010 BSI Business Systems Integration AG.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     BSI Business Systems Integration AG - initial API and implementation
 ******************************************************************************/
package org.eclipse.scout.sdk.ui.fields.proposal.nls;

import java.util.Arrays;
import java.util.Comparator;
import java.util.HashSet;
import java.util.Map.Entry;

import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.jface.dialogs.IDialogSettings;
import org.eclipse.scout.commons.CompareUtility;
import org.eclipse.scout.commons.CompositeObject;
import org.eclipse.scout.commons.StringUtility;
import org.eclipse.scout.nls.sdk.model.INlsEntry;
import org.eclipse.scout.nls.sdk.model.util.Language;
import org.eclipse.scout.sdk.ui.fields.proposal.ContentProposalProvider;
import org.eclipse.scout.sdk.ui.fields.proposal.IDialogSettingsProvider;
import org.eclipse.scout.sdk.ui.internal.ScoutSdkUi;

/**
 * <h3>{@link NlsTextContentProvider}</h3> ...
 * 
 * @author Andreas Hoegger
 * @since 3.8.0 07.02.2012
 */
public class NlsTextContentProvider extends ContentProposalProvider implements IDialogSettingsProvider {

  public static final Object NLS_NEW_PROPOSAL = new Object();

  private NlsTextLabelProvider m_labelProvider;

  public NlsTextContentProvider(NlsTextLabelProvider labelProvider) {
    m_labelProvider = labelProvider;
  }

  @Override
  public Object[] getProposals(String searchPattern, IProgressMonitor monitor) {
    HashSet<INlsEntry> entries = new HashSet<INlsEntry>();
    if (getLabelProvider().getNlsProject() != null) {
      if (!StringUtility.hasText(searchPattern)) {
        searchPattern = "*";
      }

      getLabelProvider().startRecordMatchRegions();
      NormalizedPattern pattern = createNormalizedSearchPattern(searchPattern);
      Language developmentLanguage = getLabelProvider().getNlsProject().getDevelopmentLanguage();
      for (INlsEntry entry : getLabelProvider().getNlsProject().getAllEntries()) {
        if (monitor.isCanceled()) {
          break;
        }
        // development language
        int[] matchingRegions = getMatchingRegions(entry, entry.getTranslation(developmentLanguage), pattern);
        if (matchingRegions != null) {
          entries.add(entry);
          getLabelProvider().addMatchRegions(entry, matchingRegions);
        }
        else {
          // check key
          if (getMatchingRegions(entry, entry.getKey(), pattern) != null) {
            entries.add(entry);
          }
          // also check all languages
          for (Entry<Language, String> e : entry.getAllTranslations().entrySet()) {
            if (!developmentLanguage.equals(e.getKey())) {
              if (getMatchingRegions(entry, e.getValue(), pattern) != null) {
                entries.add(entry);
                break;
              }
            }
          }
        }
      }
      INlsEntry[] nlsEntryResult = entries.toArray(new INlsEntry[entries.size()]);
      Arrays.sort(nlsEntryResult, new P_NlsEntryComparator());
      Object[] result = new Object[nlsEntryResult.length + 1];
      System.arraycopy(nlsEntryResult, 0, result, 0, nlsEntryResult.length);
      result[result.length - 1] = NLS_NEW_PROPOSAL;
      return result;
    }
    else {
      return new Object[0];
    }
  }

  public NlsTextLabelProvider getLabelProvider() {
    return m_labelProvider;
  }

  @Override
  public IDialogSettings getDialogSettings() {
    return ScoutSdkUi.getDefault().getDialogSettingsSection(NlsTextLabelProvider.class.getName(), true);
  }

  @Override
  public boolean equals(Object obj) {
    if (!(obj instanceof NlsTextContentProvider)) {
      return false;
    }
    NlsTextContentProvider ref = (NlsTextContentProvider) obj;
    return CompareUtility.equals(getLabelProvider(), ref.getLabelProvider());
  }

  private class P_NlsEntryComparator implements Comparator<INlsEntry> {
    @Override
    public int compare(INlsEntry o1, INlsEntry o2) {
      if (o1 == null) {
        return -1;
      }
      if (o2 == null) {
        return 1;
      }
      Language developmentLanguage = o1.getProject().getDevelopmentLanguage();
      return CompareUtility.compareTo(new CompositeObject(o1.getTranslation(developmentLanguage), o1.getKey()), new CompositeObject(o2.getTranslation(developmentLanguage), o2.getKey()));
    }
  }
}

==> org.eclipse.scout.sdk.ui.source_3.9.2.20140206-1207.jar: org/eclipse/scout/sdk/ui/fields/proposal/nls/NlsTextContentProvider.java <==
/*******************************************************************************
 * Copyright (c) 2010 BSI Business Systems Integration AG.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     BSI Business Systems Integration AG - initial API and implementation
 ******************************************************************************/
package org.eclipse.scout.sdk.ui.fields.proposal.nls;

import java.util.Arrays;
import java.util.HashSet;

import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.jface.dialogs.IDialogSettings;
import org.eclipse.scout.commons.CompareUtility;
import org.eclipse.scout.commons.StringUtility;
import org.eclipse.scout.nls.sdk.model.INlsEntry;
import org.eclipse.scout.nls.sdk.model.util.Language;
import org.eclipse.scout.sdk.ui.fields.proposal.ContentProposalProvider;
import org.eclipse.scout.sdk.ui.fields.proposal.IDialogSettingsProvider;
import org.eclipse.scout.sdk.ui.fields.proposal.MoreElementsProposal;
import org.eclipse.scout.sdk.ui.internal.ScoutSdkUi;

/**
 * <h3>{@link NlsTextContentProvider}</h3> ...
 * 
 * @author Andreas Hoegger
 * @since 3.8.0 07.02.2012
 */
public class NlsTextContentProvider extends ContentProposalProvider implements IDialogSettingsProvider {

  private NlsTextLabelProvider m_labelProvider;

  public NlsTextContentProvider(NlsTextLabelProvider labelProvider) {
    m_labelProvider = labelProvider;
  }

  @Override
  public Object[] getProposals(String searchPattern, IProgressMonitor monitor) {
    HashSet<NlsTextProposal> firstGroup = new HashSet<NlsTextProposal>();
    HashSet<NlsTextProposal> secondGroup = new HashSet<NlsTextProposal>();
    if (getLabelProvider().getNlsProject() != null) {
      if (!StringUtility.hasText(searchPattern)) {
        searchPattern = "*";
      }
      else {
        searchPattern = searchPattern.trim();
      }

      getLabelProvider().startRecordMatchRegions();
      NormalizedPattern pattern = createNormalizedSearchPattern(searchPattern);
      Language developmentLanguage = getLabelProvider().getNlsProject().getDevelopmentLanguage();
      for (INlsEntry entry : getLabelProvider().getNlsProject().getAllEntries()) {
        if (monitor.isCanceled()) {
          break;
        }

        NlsTextProposal candidate = new NlsTextProposal(entry, developmentLanguage);
        if (candidate.matches(pattern)) {
          int[] matchingRegions = candidate.getMatchingRegions(pattern);
          if (candidate.getMatchKind() == NlsTextProposal.MATCH_DEV_LANG_TRANSLATION) {
            firstGroup.add(candidate);
          }
          else {
            secondGroup.add(candidate);
          }
          getLabelProvider().addMatchRegions(candidate, matchingRegions);
        }
      }

      boolean hasSecondGroupItems = secondGroup.size() > 0;
      int numAdditionalElements = hasSecondGroupItems ? 2 : 1;
      Object[] nlsEntryResult = new Object[firstGroup.size() + secondGroup.size() + numAdditionalElements];

      if (firstGroup.size() > 0) {
        Object[] firstPart = firstGroup.toArray(new Object[firstGroup.size()]);
        Arrays.sort(firstPart);
        System.arraycopy(firstPart, 0, nlsEntryResult, 0, firstPart.length);
      }

      nlsEntryResult[firstGroup.size()] = NlsTextProposal.NEW_NLS_TEXT_PROPOSAL;

      if (hasSecondGroupItems) {
        nlsEntryResult[firstGroup.size() + 1] = MoreElementsProposal.INSTANCE;
        Object[] secondPart = secondGroup.toArray(new Object[secondGroup.size()]);
        Arrays.sort(secondPart);
        System.arraycopy(secondPart, 0, nlsEntryResult, firstGroup.size() + numAdditionalElements, secondPart.length);
      }
      return nlsEntryResult;
    }
    else {
      return new Object[0];
    }
  }

  public NlsTextLabelProvider getLabelProvider() {
    return m_labelProvider;
  }

  @Override
  public IDialogSettings getDialogSettings() {
    return ScoutSdkUi.getDefault().getDialogSettingsSection(NlsTextLabelProvider.class.getName(), true);
  }

  @Override
  public boolean equals(Object obj) {
    if (!(obj instanceof NlsTextContentProvider)) {
      return false;
    }
    NlsTextContentProvider ref = (NlsTextContentProvider) obj;
    return CompareUtility.equals(getLabelProvider(), ref.getLabelProvider());
  }
}
